// -*- C++ -*-
/*!
 * @file  GameController_Converter.cpp
 * @brief ModuleDescription
 * @date $Date$
 *
 * $Id$
 */

#include "GameController_Converter.h"

// Module specification
// <rtc-template block="module_spec">
static const char* gamecontroller_converter_spec[] =
  {
    "implementation_id", "GameController_Converter",
    "type_name",         "GameController_Converter",
    "description",       "ModuleDescription",
    "version",           "1.0.0",
    "vendor",            "VenderName",
    "category",          "Category",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    "conf.default.AnalogRate", "20",

    // Widget
    "conf.__widget__.AnalogRate", "text",
    // Constraints

    "conf.__type__.AnalogRate", "int",

    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
GameController_Converter::GameController_Converter(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_AnalogIn("Analog", m_Analog),
    m_velOut("vel", m_vel)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
GameController_Converter::~GameController_Converter()
{
}



RTC::ReturnCode_t GameController_Converter::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("Analog", m_AnalogIn);
  
  // Set OutPort buffer
  addOutPort("vel", m_velOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // Bind variables and configuration variable
  bindParameter("AnalogRate", m_AnalogRate, "20");
  // </rtc-template>
  
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t GameController_Converter::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GameController_Converter::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GameController_Converter::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t GameController_Converter::onActivated(RTC::UniqueId ec_id)
{
	m_vel.data.vx = 0;
	m_vel.data.vy = 0;
	m_vel.data.va = 0;

  return RTC::RTC_OK;
}


RTC::ReturnCode_t GameController_Converter::onDeactivated(RTC::UniqueId ec_id)
{

  return RTC::RTC_OK;
}


RTC::ReturnCode_t GameController_Converter::onExecute(RTC::UniqueId ec_id)
{
	// AiOXeBbN̒lXVĂꍇ
	if (m_AnalogIn.isNew())
	{
		// AiOXeBbN̒l擾
		m_AnalogIn.read();

		// Oiw
		m_vel.data.va = m_Analog.data[3] * -8.5 * m_AnalogRate / 100;
		m_vel.data.vx = m_Analog.data[2] * -0.5 * m_AnalogRate / 100;
		m_vel.data.vy = 0;
		printf("[ana]m_vel.data.vx[%f]\n", m_vel.data.vx);
		m_velOut.write();
	}
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t GameController_Converter::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GameController_Converter::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GameController_Converter::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GameController_Converter::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GameController_Converter::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void GameController_ConverterInit(RTC::Manager* manager)
  {
    coil::Properties profile(gamecontroller_converter_spec);
    manager->registerFactory(profile,
                             RTC::Create<GameController_Converter>,
                             RTC::Delete<GameController_Converter>);
  }
  
};


